@@ -4,6 +4,7 @@ import curses
 import os
 import sys
 import time
+import webbrowser
 
 import mitype.signals
 from mitype.calculations import (
@@ -14,18 +15,22 @@ from mitype.calculations import (
     speed_in_wpm,
     word_wrap,
 )
-from mitype.commandline import resolve_commandline_arguments
+from mitype.commandline import load_from_database, resolve_commandline_arguments
 from mitype.history import save_history
 from mitype.keycheck import (
     is_backspace,
+    is_ctrl_backspace,
     is_ctrl_c,
+    is_ctrl_t,
     is_enter,
     is_escape,
+    is_left_arrow_key,
     is_resize,
+    is_right_arrow_key,
     is_tab,
     is_valid_initial_key,
 )
-from mitype.timer import get_elapsed_minutes_since_first_keypress
+from mitype.timer import get_elapsed_seconds_since_first_keypress
 
 
 class App:
@@ -48,6 +53,7 @@ class App:
         self.key = ""
         self.first_key_pressed = False
         self.key_strokes = []
+        self.mistyped_keys = []
 
         self.start_time = 0
         self.end_time = 0
@@ -100,6 +106,12 @@ class App:
             if is_ctrl_c(key):
                 sys.exit(0)
 
+            if is_left_arrow_key(key) and not self.first_key_pressed:
+                self.switch_text(win, -1)
+
+            if is_right_arrow_key(key) and not self.first_key_pressed:
+                self.switch_text(win, 1)
+
             # Test mode
             if self.mode == 0:
                 self.typing_mode(win, key)
@@ -116,15 +128,35 @@ class App:
                 # Start replay if enter key is pressed
                 self.replay(win)
 
+            # Share result on Twitter
+            elif self.mode == 1 and is_ctrl_t(key):
+                # Opens twitter with pre-typed result
+                self.share_result()
+
             # Refresh for changes to show up on window
             win.refresh()
 
+    def share_result(self):
+        """Open a twitter intent on a browser."""
+        message = (
+            "My typing speed is "
+            + self.current_speed_wpm
+            + " WPM! Know yours on mitype."
+            + "\nhttps://pypi.org/project/mitype/ by @MithilPoojary"
+            + "\n#TypingTest"
+        )
+
+        # URL encode message
+        message = message.replace("\n", "%0D").replace("#", "%23")
+        url = "https://twitter.com/intent/tweet?text=" + message
+        webbrowser.open(url, new=2)
+
     def typing_mode(self, win, key):
         """Start recording typing session progress.
 
         Args:
             win (any): Curses window.
-            key (string): First typed character of the session.
+            key (str): First typed character of the session.
         """
         # Note start time when first valid key is pressed
         if not self.first_key_pressed and is_valid_initial_key(key):
@@ -143,16 +175,12 @@ class App:
 
         self.key_printer(win, key)
 
-    def screen_size_check(self, window_height, window_width, text):
-        """Check if screen size is enough to print text.
-
-        Args:
-            win (any): Curses window.
-        """
+    def screen_size_check(self):
+        """Check if screen size is enough to print text."""
         self.line_count = (
             number_of_lines_to_fit_text_in_window(self.text, self.window_width) + 2 + 1
         )
-        if self.line_count + 5 >= self.window_height:
+        if self.line_count + 7 >= self.window_height:
             curses.endwin()
             sys.stdout.write("Window too small to print given text")
             sys.exit(1)
@@ -166,10 +194,10 @@ class App:
         # Find window dimensions
         self.window_height, self.window_width = self.get_dimensions(win)
 
-        # Adding word wrap to text
+        # Add word wrap to text
         self.text = word_wrap(self.text, self.window_width)
 
-        self.screen_size_check(self.window_height, self.window_width, self.text)
+        self.screen_size_check()
 
         curses.init_pair(1, curses.COLOR_WHITE, curses.COLOR_GREEN)
         curses.init_pair(2, curses.COLOR_WHITE, curses.COLOR_RED)
@@ -212,7 +240,7 @@ class App:
 
         Args:
             win (any): Curses window object.
-            key (string): Individual characters are returned as 1-character
+            key (str): Individual characters are returned as 1-character
                 strings, and special keys such as function keys
                 return longer strings containing a key name such as
                 KEY_UP or ^G.
@@ -232,8 +260,11 @@ class App:
         elif is_backspace(key):
             self.erase_key()
 
+        elif is_ctrl_backspace(key):
+            self.erase_word()
+
         # Ignore spaces at the start of the word (Plover support)
-        elif key == " ":
+        elif key == " " and len(self.current_word) < self.current_word_limit:
             if self.current_word != "":
                 self.check_word()
 
@@ -250,6 +281,18 @@ class App:
             self.current_word = self.current_word[0 : len(self.current_word) - 1]
             self.current_string = self.current_string[0 : len(self.current_string) - 1]
 
+    def erase_word(self):
+        """Erase the last typed word."""
+        if len(self.current_word) > 0:
+            index_word = self.current_word.rfind(" ")
+            diff = len(self.current_word) - index_word
+            if index_word == -1:
+                self.current_string = self.current_string[: -len(self.current_word)]
+                self.current_word = ""
+            else:
+                self.current_word = self.current_word[:-diff]
+                self.current_string = self.current_string[:-diff]
+
     def check_word(self):
         """Accept finalized word."""
         spc = get_space_count_after_ith_word(len(self.current_string), self.text)
@@ -265,7 +308,7 @@ class App:
         """Append a character to the end of the current word.
 
         Args:
-            key (key): character to append
+            key (key): Character to append.
         """
         if len(self.current_word) < self.current_word_limit:
             self.current_word += key
@@ -277,7 +320,7 @@ class App:
         Args:
             win (any): Curses window.
         """
-        total_time = mitype.timer.get_elapsed_minutes_since_first_keypress(
+        total_time = mitype.timer.get_elapsed_seconds_since_first_keypress(
             self.start_time
         )
         current_wpm = 0
@@ -310,6 +353,9 @@ class App:
         win.addstr(2, 0, self.text[0 : len(self.current_string)], curses.A_DIM)
 
         index = first_index_at_which_strings_differ(self.current_string, self.text)
+        # Check if difference was found
+        if index < len(self.current_string):
+            self.mistyped_keys.append(len(self.current_string) - 1)
 
         win.addstr(
             2 + index // self.window_width,
@@ -318,6 +364,15 @@ class App:
             curses.color_pair(2),
         )
         if index == len(self.text):
+            # Highlight mistyped characters
+            for i in self.mistyped_keys:
+                win.addstr(
+                    2 + i // self.window_width,
+                    i % self.window_width,
+                    self.text[i],
+                    curses.color_pair(2),
+                )
+
             curses.curs_set(0)
 
             win.addstr(self.line_count, 0, " Your typing speed is ")
@@ -327,7 +382,7 @@ class App:
                     self.text_without_spaces
                 )
                 self.accuracy = accuracy(self.total_chars_typed, wrongly_typed_chars)
-                self.time_taken = get_elapsed_minutes_since_first_keypress(
+                self.time_taken = get_elapsed_seconds_since_first_keypress(
                     self.start_time
                 )
 
@@ -339,7 +394,11 @@ class App:
             win.addstr(self.line_count + 2, 1, " Enter ", curses.color_pair(7))
             win.addstr(" to see replay, ")
             win.addstr(" Tab ", curses.color_pair(7))
-            win.addstr(" to retry ")
+            win.addstr(" to retry.")
+            win.addstr(self.line_count + 3, 1, " Arrow keys ", curses.color_pair(7))
+            win.addstr(" to change text.")
+            win.addstr(self.line_count + 4, 1, " CTRL+T ", curses.color_pair(7))
+            win.addstr(" to tweet result.")
 
             self.print_stats(win)
             if self.mode == 0:
@@ -369,6 +428,7 @@ class App:
         self.current_string = ""
         self.first_key_pressed = False
         self.key_strokes = []
+        self.mistyped_keys = []
         self.start_time = 0
         self.i = 0
         self.current_speed_wpm = 0
@@ -378,7 +438,7 @@ class App:
         curses.curs_set(1)
 
     def replay(self, win):
-        """Play out a recording of the users last session.
+        """Play out a recording of the user's last session.
 
         Args:
             win (any): Curses window.
@@ -418,7 +478,7 @@ class App:
         self.window_height, self.window_width = self.get_dimensions(win)
         self.text = word_wrap(self.original_text_formatted, self.window_width)
 
-        self.screen_size_check(self.window_height, self.window_width, self.text)
+        self.screen_size_check()
 
         self.print_realtime_wpm(win)
         self.setup_print(win)
@@ -433,7 +493,7 @@ class App:
         win.addstr(
             self.window_height - 1,
             0,
-            " WPM: " + self.current_speed_wpm + " ",
+            " WPM: " + str(self.current_speed_wpm) + " ",
             curses.color_pair(6),
         )
 
@@ -447,15 +507,38 @@ class App:
             curses.color_pair(5),
         )
 
+    def switch_text(self, win, value):
+        """Load next or previous text snippet from database.
+
+        Args:
+            win (any): Curses window.
+            value (int): value to increase or decrement the text ID by.
+        """
+        if isinstance(self.text_id, str):
+            return
+
+        win.clear()
+
+        self.text_id += value
+        self.text = load_from_database(self.text_id)[0]
+        self.tokens = self.text.split()
+
+        self.text = " ".join(self.tokens)
+        self.original_text_formatted = self.text
+
+        self.reset_test()
+        self.setup_print(win)
+        self.update_state(win)
+
     @staticmethod
     def get_dimensions(win):
-        """Get the width of terminal.
+        """Get the height and width of terminal.
 
         Args:
             win (any): Curses window object.
 
         Returns:
-            int: Return width of terminal window.
+            (int, int): Tuple of height and width of terminal window.
         """
         dimension_tuple = win.getmaxyx()
 
@@ -473,10 +556,6 @@ class App:
         """
         key = ""
         try:
-            if sys.version_info[0] < 3:
-                key = win.getkey()
-                return key
-
             key = win.get_wch()
             if isinstance(key, int):
                 if key in (curses.KEY_BACKSPACE, curses.KEY_DC):
