@@ -112,14 +112,15 @@ def load_text_from_file(file_path):
     """Load file contents.
 
     Args:
-        file_path (string): Full path to text to load.
+        file_path (str): Full path to text to load.
 
     Returns:
         (str, str): Tuple of text content followed by file path.
     """
     if os.path.isfile(file_path):
-        text = open(file_path).read()
-        filename = os.path.basename(file_path)
+        with open(file_path) as file:
+            text = file.read()
+            filename = os.path.basename(file_path)
         return text, filename
 
     print("Cannot open file -", file_path)
